==> haskell-insert-ordered-containers-0.2.5-17-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-insert-ordered-containers.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 insert-ordered-containers
version:              0.2.5
visibility:           public
id:                   insert-ordered-containers-0.2.5-LeRdBoJ4FbzKv9FT4qSr9D
key:                  insert-ordered-containers-0.2.5-LeRdBoJ4FbzKv9FT4qSr9D
license:              BSD-3-Clause
maintainer:           Oleg Grenrus <oleg.grenrus@iki.fi>
author:               Oleg Grenrus <oleg.grenrus@iki.fi>
homepage:             https://github.com/phadej/insert-ordered-containers#readme
synopsis:
    Associative containers retaining insertion order for traversals.

description:
    Associative containers retaining insertion order for traversals.

    The implementation is based on `unordered-containers`.

category:             Web
abi:                  3c682332800494e7eeebfa4ee02ac1be
exposed:              True
exposed-modules:      Data.HashMap.Strict.InsOrd Data.HashSet.InsOrd
hidden-modules:       Data.HashMap.InsOrd.Internal
import-dirs:
    /usr/lib/ghc-9.0.1/site-local/insert-ordered-containers-0.2.5

library-dirs:
    /usr/lib/ghc-9.0.1/site-local/insert-ordered-containers-0.2.5

dynamic-library-dirs: /usr/lib
data-dir:
    /usr/share/x86_64-linux-ghc-9.0.1/insert-ordered-containers-0.2.5

hs-libraries:         HSinsert-ordered-containers-0.2.5-LeRdBoJ4FbzKv9FT4qSr9D
depends:
    aeson-1.5.6.0-EMNFVE8fJ8l4Y3HGKS2Pru base-4.15.0.0
    base-compat-0.11.2-EfuzzJ3SbjR74eBdJgKfBC deepseq-1.4.5.0
    hashable-1.3.2.0-2579b4ed8EpGiVuNwiQjKE
    indexed-traversable-0.1.1-K0YsJRCif6Q7nMYcYE7GvA
    lens-5.0.1-FdpuvmTBMS53qHfLYlRUsS
    optics-core-0.4-93Dqg26YwQUDlxX9SGGdaY
    optics-extra-0.4-KtgtgkQu9bj7ImregtclUw
    semigroupoids-5.3.5-HXBtEdHlc3rJZTpH0VHqFx text-1.2.4.1
    transformers-0.5.6.2
    unordered-containers-0.2.14.0-9dFFYFCso8sGtsfFV1YYEC

haddock-interfaces:
    /usr/share/doc/haskell-insert-ordered-containers/html/insert-ordered-containers.haddock

haddock-html:         /usr/share/doc/haskell-insert-ordered-containers/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-insert-ordered-containers-0.2.5-19-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-insert-ordered-containers.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 insert-ordered-containers
version:              0.2.5
visibility:           public
id:                   insert-ordered-containers-0.2.5-5Jqw2vXL6P73FM9AvsvjTn
key:                  insert-ordered-containers-0.2.5-5Jqw2vXL6P73FM9AvsvjTn
license:              BSD-3-Clause
maintainer:           Oleg Grenrus <oleg.grenrus@iki.fi>
author:               Oleg Grenrus <oleg.grenrus@iki.fi>
homepage:             https://github.com/phadej/insert-ordered-containers#readme
synopsis:
    Associative containers retaining insertion order for traversals.

description:
    Associative containers retaining insertion order for traversals.

    The implementation is based on `unordered-containers`.

category:             Web
abi:                  74f8eae5001851a1488e0c1a91cc3009
exposed:              True
exposed-modules:      Data.HashMap.Strict.InsOrd Data.HashSet.InsOrd
hidden-modules:       Data.HashMap.InsOrd.Internal
import-dirs:
    /usr/lib/ghc-9.0.1/site-local/insert-ordered-containers-0.2.5

library-dirs:
    /usr/lib/ghc-9.0.1/site-local/insert-ordered-containers-0.2.5

dynamic-library-dirs: /usr/lib
data-dir:
    /usr/share/x86_64-linux-ghc-9.0.1/insert-ordered-containers-0.2.5

hs-libraries:         HSinsert-ordered-containers-0.2.5-5Jqw2vXL6P73FM9AvsvjTn
depends:
    aeson-1.5.6.0-FdusChH0dokB9fXPeFrIPu base-4.15.0.0
    base-compat-0.11.2-EfuzzJ3SbjR74eBdJgKfBC deepseq-1.4.5.0
    hashable-1.3.2.0-2579b4ed8EpGiVuNwiQjKE
    indexed-traversable-0.1.1-K0YsJRCif6Q7nMYcYE7GvA
    lens-5.0.1-BleJmcgZntS7OUJObTA7W5
    optics-core-0.4-93Dqg26YwQUDlxX9SGGdaY
    optics-extra-0.4-CaWMsHIJB5xEkxQoZDgz83
    semigroupoids-5.3.5-G0ouO61PJXREafQ2I2F8en text-1.2.4.1
    transformers-0.5.6.2
    unordered-containers-0.2.14.0-4VkaQXrxHxDFVxUpdGbpuH

haddock-interfaces:
    /usr/share/doc/haskell-insert-ordered-containers/html/insert-ordered-containers.haddock

haddock-html:         /usr/share/doc/haskell-insert-ordered-containers/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
